# [media_metadata_retriever](https://github.com/alexmercerind/media_metadata_retriever)

Flutter plugin for reading :bookmark: metadata of :musical_note: media files.

## :floppy_disk: Install

```yaml
dependencies:
  media_metadata_retriever: ^0.0.2+1
```

## :triangular_ruler: Usage

```dart
import 'package:media_metadata_retriever/media_metadata_retriever.dart';

Future<Map<String, dynamic>> getFromFile() async {
    final retriever = new MediaMetadataRetriever();
    /* Set a file path. */
    await retriever.setFile(new File('/storage/emulated/0/Music/music.aac'));
    /* Read metadata. */
    Metadata metadata = await retriever.metadata;
    metadata.trackName;
    metadata.trackArtistNames;
    metadata.albumName;
    metadata.albumArtistName;
    metadata.trackNumber;
    metadata.albumLength;
    metadata.year;
    metadata.genre;
    metadata.authorName;
    metadata.writerName;
    metadata.discNumber;
    metadata.mimeType;
    metadata.trackDuration;
    metadata.bitrate;
    /* Access album art as Uint8List. Use [Image.memory] to show it inside the app. */
    retriever.albumArt;
    /* Convert metadata to a Map<String, dynamic>. */
    return metadata.toMap();
}

Future<Map<String, dynamic>> getFromUri() async {
  final retriever = new MediaMetadataRetriever();
  await retriever.setUri(new Uri.https('www.example.com', '/audio.MP3', {}));
  return (await retriever.metadata).toMap();
}
```

## :iphone: Example

You may checkout example app for this plugin [here](https://github.com/alexmercerind/media_metadata_retriever/tree/master/example/lib/main.dart).


|Screenshot 1                                                                                                   |Screenshot 2                                                                                       |
|---------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------|
|![](https://github.com/alexmercerind/media_metadata_retriever/blob/master/screenshots/screenshot0.png?raw=true)|![](https://github.com/alexmercerind/media_metadata_retriever/blob/master/screenshots/screenshot1.png?raw=true)|


## :heavy_check_mark: Progress

|Platform|Status     |
|--------|-----------|
|Android |Working    |
|Linux   |Coming Soon|
|Windows |Not Working|


## :safety_pin: How?

[MediaMetadataRetriever](https://developer.android.com/reference/android/media/MediaMetadataRetriever) on Android does the job. Pretty easy right?
